@@ -8,25 +8,28 @@
 #define HAVE_DECL_ADDR_NO_RANDOMIZE 1
 #define HAVE_ARC4RANDOM_UNIFORM 0
 #define HAVE_EXPLICIT_BZERO 1
+#define HAVE_EXPLICIT_MEMSET 0
+#define HAVE_CLOCK_NANOSLEEP 1
+#define HAVE_SIGACTION 1
 
 #ifdef R_MESON_VERSION
 #define R2_PREFIX "/usr"
 #define R2_LIBDIR "/usr/lib"
-#define R2_INCDIR "/usr/include"
+#define R2_INCDIR "/usr/include/libr"
 #define R2_DATDIR "/usr/share"
-#define R2_WWWROOT "@WWWROOT@"
-#define R2_PLUGINS "@PLUGINS@"
-#define R2_EXTRAS "@EXTRAS@"
-#define R2_BINDINGS "@BINDINGS@"
-#define R2_DATDIR_R2 "@DATADIR_R2@"
-#define R2_SDB "@SDB@"
-#define R2_ZIGNS "@ZIGNS@"
-#define R2_THEMES "@THEMES@"
-#define R2_FORTUNES "@FORTUNES@"
-#define R2_FLAGS "@FLAGS@"
-#define R2_HUD "@HUD@"
+#define R2_WWWROOT "/usr/share/radare2/4.3.1/www"
+#define R2_PLUGINS "lib/radare2/4.3.1"
+#define R2_EXTRAS "lib/radare2-extras/4.3.1"
+#define R2_BINDINGS "lib/radare2-bindings/4.3.1"
+#define R2_DATDIR_R2 "share/radare2"
+#define R2_SDB "share/radare2/4.3.1"
+#define R2_ZIGNS "share/radare2/4.3.1/zigns"
+#define R2_THEMES "share/radare2/4.3.1/cons"
+#define R2_FORTUNES "share/doc/radare2"
+#define R2_FLAGS "share/radare2/4.3.1/flag"
+#define R2_HUD "share/radare2/4.3.1/hud"
 #else
-#if __WINDOWS__ || __CYGWIN__ || MINGW32 || _MSC_VER || CUTTER
+#if __WINDOWS__ || _MSC_VER
 #define R2_PREFIX "."
 #define R2_LIBDIR "lib"
 #define R2_INCDIR "include\\libr"
@@ -38,7 +41,7 @@
 #else
 #define R2_PREFIX "/usr"
 #define R2_LIBDIR "/usr/lib"
-#define R2_INCDIR "/usr/include/libr"
+#define R2_INCDIR "/usr/include/libr/libr"
 #define R2_DATDIR "/usr/share"
 #define R2_WWWROOT R2_DATDIR "/radare2/" R2_VERSION "/www"
 #define R2_PLUGINS "lib/radare2/" R2_VERSION
@@ -81,20 +84,22 @@
 #define R2_GLOBAL_RC        R_JOIN_2_PATHS (R2_DATDIR_R2, "radare2rc")
 
 #define HAVE_LIB_MAGIC 1
-#define USE_LIB_MAGIC 0
-#define HAVE_LIB_XXHASH 0
-#define USE_LIB_XXHASH 0
+#define USE_LIB_MAGIC 1
+#define HAVE_LIB_XXHASH 1
+#define USE_LIB_XXHASH 1
 
 #ifndef HAVE_LIB_SSL
 #define HAVE_LIB_SSL 1
 #endif
 
-#define HAVE_LIBUV 0
+#define HAVE_LIBUV 1
 
 #define HAVE_PTRACE 1
 #define USE_PTRACE_WRAP 1
 #define HAVE_FORK 1
 
+#define USE_TREESITTER 0
+
 #define WITH_GPL 1
 
 #if __APPLE__ && __POWERPC__
